import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal
} from 'd3';
import { dropdownMenu } from './dropdownMenu';

dropdownMenu(select('body'), {
	option:['a', 'b', 'c']
});

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Life Satisfaction: Year v.s. Happiness Rank';
  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.Dementia;
  const circleRadius = 6;
  const yAxisLabel = 'Total Deaths';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/Chooo4u/datasets/annual deaths causes in usa.csv')
  .then(data => {
    data.forEach(d => {
      d['Year'] = Date.parse(+d['Year']);
      d['Dementia'] = +d['Dementia'];
      d['Cardiovascular diseases'] = +d['Cardiovascular diseases'];
      d['Kidney disease'] = +d['Kidney disease'];
      d['Respiratory disease'] = +d['Respiratory disease'];
      d['Liver disease'] = +d['Liver disease'];
      d['Diabetes, blood and endocrine disease'] = +d['Diabetes, blood and endocrine disease'];
      d['Digestive disease'] = +d['Digestive disease'];
      d['Hepatitis'] = +d['Hepatitis'];
      d['Cancers'] = +d['Cancers'];
      d['Fire'] = +d['Fire'];
      d['Drowning'] = +d['Drowning'];
      d['Homicide'] = +d['Homicide'];
      d['HIV/AIDS'] = +d['HIV/AIDS'];
      d['Drug disorder'] = +d['Drug disorder'];
      d['Tuberculosis'] = +d['Tuberculosis'];
      d['Road incidents'] = +d['Road incidents'];
      d['Alcohol disorder'] = +d['Alcohol disorder'];
      d['Natural disasters'] = +d['Natural disasters'];
      d['Diarrheal diseases'] = +d['Diarrheal diseases'];
      d['Heat-related deaths (hot or cold exposure)'] = +d['Heat-related deaths (hot or cold exposure)'];
      d['Nutritional deficiencies'] = +d['Nutritional deficiencies'];
      d['Suicide'] = +d['Suicide'];
      d['Meningitis (deaths)'] = +d['Meningitis (deaths)'];
      d['Lower respiratory infections (deaths)'] = +d['Lower respiratory infections (deaths)']	;
      d['Intestinal infectious diseases (deaths'] = +d['Intestinal infectious diseases (deaths'];
      d['Protein-energy malnutrition (deaths)'] = +d['Protein-energy malnutrition (deaths)'];
      d['Conflict (deaths)'] = +d['Conflict (deaths)'];
      d['Terrorism (deaths)'] = +d['Terrorism (deaths)'];
    });
    render(data);
  });